@@ -955,23 +955,30 @@ g_vfs_backend_admin_pre_setup (int *argc,
   GError *error = NULL;
   GOptionContext *context;
 
+  context = g_option_context_new (NULL);
+  g_option_context_set_ignore_unknown_options (context, TRUE);
+  g_option_context_add_main_entries (context, entries, GETTEXT_PACKAGE);
+  g_option_context_parse (context, argc, argv, &error);
+  g_option_context_free (context);
+  if (error != NULL)
+    {
+      g_printerr ("Can't parse arguments: %s", error->message);
+      g_error_free (error);
+      exit (1);
+    }
+
   pkexec_uid = g_getenv ("PKEXEC_UID");
   if (pkexec_uid == NULL)
-    g_error ("gvfsd-admin must be executed under pkexec");
+    {
+      g_printerr ("gvfsd-admin must be executed under pkexec\n");
+      exit (1);
+    }
 
   errno = 0;
   uid = strtol (pkexec_uid, NULL, 10);
   if (errno != 0)
     g_error ("Unable to convert PKEXEC_UID string to uid_t");
 
-  context = g_option_context_new (NULL);
-  g_option_context_set_ignore_unknown_options (context, TRUE);
-  g_option_context_add_main_entries (context, entries, GETTEXT_PACKAGE);
-  g_option_context_parse (context, argc, argv, &error);
-
-  if (error != NULL)
-    g_error ("Can't parse arguments: %s", error->message);
-
   acquire_caps (uid);
   g_setenv ("DBUS_SESSION_BUS_ADDRESS", session_address, TRUE);
 }
