@@ -122,7 +122,7 @@ run (GVfsJob *job)
   if (class->push == NULL)
     {
       g_vfs_job_failed (job, G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED,
-			_("Operation not supported by backend"));
+			_("Operation not supported"));
       return;
     }
 
@@ -136,9 +136,6 @@ run (GVfsJob *job)
                op_job->remove_source,
                progress_job->send_progress ? g_vfs_job_progress_callback : NULL,
                progress_job->send_progress ? job : NULL);
-  
-  if (progress_job->progress_proxy)
-    g_clear_object (&progress_job->progress_proxy);
 }
 
 static gboolean
@@ -162,9 +159,6 @@ try (GVfsJob *job)
                          op_job->remove_source,
                          progress_job->send_progress ? g_vfs_job_progress_callback : NULL,
                          progress_job->send_progress ? job : NULL);
-  
-  if (progress_job->progress_proxy)
-    g_clear_object (&progress_job->progress_proxy);
 
   return res;
 }
